@@ -1,4 +1,5 @@
 ## Copyright (C) 1999 Andy Adler <adler@sce.carleton.ca>
+##
 ## Copyright (C) 2008 Søren Hauberg <soren@hauberg.org>
 ## Copyright (C) 2015 Hartmut Gimpel <hg_code@gmx.de>
 ## Copyright (C) 2015 Carnë Draug <carandraug@octave.org>
@@ -29,8 +30,6 @@
 ## the threshold value used to identify those edges.  Note that @var{thresh}
 ## is used on a filtered image and not directly on @var{im}.
 ##
-## @seealso{fspecial}
-##
 ## @end deftypefn
 ## @deftypefn  {Function File} {} edge (@var{im}, @qcode{"Canny"})
 ## @deftypefnx {Function File} {} edge (@var{im}, @qcode{"Canny"}, @var{thresh})
@@ -154,6 +153,8 @@
 ## @end table
 ## defaults = [8, 1, 3, 3]
 ##
+## @seealso{fspecial}
+##
 ## @end deftypefn
 
 function [bw_out, thresh, varargout] = edge (im, method = "sobel", varargin)
@@ -401,7 +402,7 @@ function [bw, thresh] = edge_canny (im, thresh = [], sigma = sqrt (2))
   else
     thresh = thresh(:).'; # always return a row vector
   endif
-  bw = nonmax_supress(Es, Eo, thresh(1), thresh(2));
+  bw = nonmax_suppress(Es, Eo, thresh(1), thresh(2));
 endfunction
 
 function [bw] = edge_lindeberg (im, sigma = 2)
