@@ -1,3 +1,22 @@
+## Copyright (C) 2013-2015 Carnë Draug <carandraug@octave.org>
+##
+## This program is free software; you can redistribute it and/or
+## modify it under the terms of the GNU General Public License as
+## published by the Free Software Foundation; either version 3 of the
+## License, or (at your option) any later version.
+##
+## This program is distributed in the hope that it will be useful, but
+## WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+## General Public License for more details.
+##
+## You should have received a copy of the GNU General Public License
+## along with this program; if not, see
+## <http://www.gnu.org/licenses/>.
+##
+## This file incorporates work covered by the following copyright and
+## permission notice:
+##
 ## Copyright (C) 2004 Stefan van der Walt <stefan@sun.ac.za>
 ## All rights reserved.
 ##
@@ -105,12 +124,12 @@ endfunction
 %!test
 %! a = repmat (1:10, 5);
 %! b = repmat (10:-1:3, 7);
-%! assert (fftconv2 (a, b), conv2 (a, b), 1.3e4*eps)
-%! assert (fftconv2 (b, a), conv2 (b, a), 1.3e4*eps)
-%! assert (fftconv2 (a, b, "full"), conv2 (a, b, "full"), 1.3e4*eps)
-%! assert (fftconv2 (b, a, "full"), conv2 (b, a, "full"), 1.3e4*eps)
-%! assert (fftconv2 (a, b, "same"), conv2 (a, b, "same"), 1e4*eps)
-%! assert (fftconv2 (b, a, "same"), conv2 (b, a, "same"), 1e4*eps)
+%! assert (fftconv2 (a, b), conv2 (a, b), 1.8e4*eps)
+%! assert (fftconv2 (b, a), conv2 (b, a), 1.8e4*eps)
+%! assert (fftconv2 (a, b, "full"), conv2 (a, b, "full"), 1.8e4*eps)
+%! assert (fftconv2 (b, a, "full"), conv2 (b, a, "full"), 1.8e4*eps)
+%! assert (fftconv2 (a, b, "same"), conv2 (a, b, "same"), 1.8e4*eps)
+%! assert (fftconv2 (b, a, "same"), conv2 (b, a, "same"), 1.8e4*eps)
 %! assert (isempty (fftconv2 (a, b, "valid")));
 %! assert (fftconv2 (b, a, "valid"),  conv2 (b, a, "valid"), 1e4*eps)
 
@@ -144,5 +163,3 @@ endfunction
 %! subplot (1, 3, 3)
 %! imshow (fc, [min(fc(:)) max(fc(:))])
 %! title ("Convolution in the frequency domain")
-
-
