@@ -22,7 +22,6 @@
 ## that follow are type specific.  The return value is a correlation kernel,
 ## often to be used by @code{imfilter}.
 ##
-## @seealso{conv2, convn, filter2, imfilter}
 ## @end deftypefn
 ##
 ## @deftypefn  {Function File} {} fspecial ("average")
@@ -158,6 +157,8 @@
 ##  -5 -5 -5 ]
 ## @end example
 ##
+## @seealso{conv2, convn, filter2, imfilter}
+##
 ## @end deftypefn
 
 ## Remarks by Søren Hauberg (jan. 2nd 2007)
@@ -309,7 +310,7 @@ function f = fspecial (type, arg1, arg2)
       pos = arrayfun ("colon", -lengths, lengths, "uniformoutput", false);
       dist = 0;
       for d = 1:numel(lengths)
-        dist = dist .+ (vec (pos{d}, d) .^2); # broadcasting with '.+=' does not work
+        dist = dist + (vec (pos{d}, d) .^2);
       endfor
       f = exp (- (dist) / (2 * (sigma.^2)));
       f /= sum (f(:));
@@ -460,8 +461,8 @@ endfunction
 %!assert (fspecial ("gaussian"), fspecial ("gaussian", [3 3], 0.5))
 
 %!test
-%! c = ([-1:1].^2) .+ ([-1:1]'.^2);
-%! gauss = exp (- (c ./ (2 * (0.5 .^ 2))));
+%! c = ([-1:1].^2) + ([-1:1]'.^2);
+%! gauss = exp (- (c / (2 * (0.5 ^ 2))));
 %! f = gauss / sum (gauss(:));
 %! assert (fspecial ("gaussian"), f)
 %!
@@ -475,7 +476,7 @@ endfunction
 ## against some of the values.  Note that hsize is (radius -1) and
 ## only works for odd lengths.
 %!function f = f_gaussian_2d (hsize, sigma)
-%!  c = ([(-hsize(1)):(hsize(1))]'.^2) .+ ([(-hsize(2)):(hsize(2))].^2);
+%!  c = ([(-hsize(1)):(hsize(1))]'.^2) + ([(-hsize(2)):(hsize(2))].^2);
 %!  gauss = exp (- (c ./ (2 * (sigma .^ 2))));
 %!  f = gauss ./ sum (gauss(:));
 %!endfunction
