@@ -263,15 +263,17 @@ function im = imresize (im, varargin)
     if (iscell (method))
       kernel_size = method{2};
       if (scale < 1 && antialiasing)
-        kernel = @(h) scale * method{1} (scale * h);
-        kernel_size /= scale;
+        scale_int = 1 / ceil (1 / scale);
+        kernel = @(h) scale_int * method{1} (scale_int * h);
+        kernel_size /= scale_int;
       else
         kernel = method{1};
       endif
     elseif (strcmp (method, "nearest"))
       if (scale < 1)
-        kernel = @(h) scale * box (scale * h);
-        kernel_size = 1 / scale;
+        scale_int = 1 / ceil (1 / scale);
+        kernel = @(h) scale_int * box (scale_int * h);
+        kernel_size = 1 / scale_int;
       else
         if axis == 1
           im = im(round (idx), :, :);
@@ -283,16 +285,18 @@ function im = imresize (im, varargin)
     elseif (strcmp (method, "linear"))
       kernel_size = 2;
       if (scale < 1 && antialiasing)
-        kernel = @(h) scale * triangle (scale * h);
-        kernel_size /= scale;
+        scale_int = 1 / ceil (1 / scale);
+        kernel = @(h) scale_int * triangle (scale_int * h);
+        kernel_size /= scale_int;
       else
         kernel = @triangle;
       endif
     elseif (strcmp (method, "cubic"))
       kernel_size = 4;
       if (scale < 1 && antialiasing)
-        kernel = @(h) scale * cubic (scale * h);
-        kernel_size /= scale;
+        scale_int = 1 / ceil (1 / scale);
+        kernel = @(h) scale_int * cubic (scale_int * h);
+        kernel_size /= scale_int;
       else
         kernel = @cubic;
       endif
@@ -796,3 +800,13 @@ endfunction
 %! r_small_double = randi(16000, 100, 100);
 %! tic; imresize (r_small_int16,  8000/100); toc;
 %! tic; imresize (r_small_double, 8000/100); toc;
+
+## test for stripes when downscaling with antialiasing (bug #63560)
+%!test
+%! im = 0.5 .* ones (30);
+%! out1 = imresize (im, 0.55, "bilinear", "antialiasing", true);
+%! out2 = imresize (im, 0.55, "bicubic", "antialiasing", true);
+%! out3 = imresize (im, 0.55, "nearest", "antialiasing", true);
+%! assert (std (out1(:)), 0, 10*eps);
+%! assert (std (out2(:)), 0, 10*eps);
+%! assert (std (out3(:)), 0, 10*eps);
