@@ -133,7 +133,7 @@ function low_high = stretchlim (img, tol = [0.01 0.99])
     low_high = [min(img, [], 1); max(img, [], 1)];
   else
     strides = reshape ((0:plane_length:(numel(img)-1)), [1 sz(3:end)]);
-    lo_hi_idx = [lo_idx; hi_idx] .+ strides;
+    lo_hi_idx = [lo_idx; hi_idx] + strides;
     sorted = sort (img, 1);
     low_high = sorted(lo_hi_idx);
   endif
@@ -286,18 +286,18 @@ endfunction
 ## TOL is the limit, we must saturate the top and bottom 9 pixels (not 10).
 %!assert (stretchlim (0.01:.001:1), [0.019; 0.991], eps)
 %!assert (stretchlim (0.01:.001:1, [0.01,0.95]), [0.019; 0.951], eps)
-%!assert (stretchlim (0.01:.001:1, 0), [0.01; 1])
+%!assert (stretchlim (0.01:.001:1, 0), [0.01; 1], eps)
 %!assert (stretchlim (single (0.01:.001:1)),
-%!         double (single (0.01:.001:1)([10; 982])).')
+%!         double (single (0.01:.001:1)([10; 982])).', eps)
 
 ## Test ignoring floating point values outside [0 1] and how they do
 ## count for the fraction of saturated values, but are simply clipped
 ## to the [0 1] range
 %!test
 %! assert (stretchlim ([(.05:.05:1) (2:4)], 0.2), [0.25; 0.95], eps)
-%! assert (stretchlim ([(.05:.05:1) (2:5)], 0.2), [0.25; 1])
-%! assert (stretchlim ([(.05:.05:1) (2:6)], 0.2), [0.3; 1])
-%! assert (stretchlim ([(.05:.05:1) (2:7)], 0.2), [0.3; 1])
+%! assert (stretchlim ([(.05:.05:1) (2:5)], 0.2), [0.25; 1], eps)
+%! assert (stretchlim ([(.05:.05:1) (2:6)], 0.2), [0.3; 1], eps)
+%! assert (stretchlim ([(.05:.05:1) (2:7)], 0.2), [0.3; 1], eps)
 
 %!test
 %! assert (stretchlim ([(-6:0) (.05:.05:1)], 0.2), [0; 0.75], eps)
