@@ -55,14 +55,14 @@ custom_gaussian_smoothing (const MT &I, const Matrix &lambda1, const Matrix &lam
               const double k = 3.0; // The maximally allowed Mahalanobis' distance
               const double sqrtv1 = sqrt (v1);
               const double sqrtv2 = sqrt (v2);
-              const octave_idx_type rur = abs (k*(ct*sqrtv2 - st*sqrtv1)); // 'rur' means 'row-upper-right'
-              const octave_idx_type cur = abs (k*(st*sqrtv2 + ct*sqrtv1));
-              const octave_idx_type rlr = abs (k*(ct*sqrtv2 + st*sqrtv1));
-              const octave_idx_type clr = abs (k*(st*sqrtv2 - ct*sqrtv1));
-              const octave_idx_type rul = abs (k*(-ct*sqrtv2 - st*sqrtv1));
-              const octave_idx_type cul = abs (k*(-st*sqrtv2 + ct*sqrtv1));
-              const octave_idx_type rll = abs (k*(-ct*sqrtv2 + st*sqrtv1));
-              const octave_idx_type cll = abs (k*(-st*sqrtv2 - ct*sqrtv1));
+              const octave_idx_type rur = (octave_idx_type)std::fabs (k*(ct*sqrtv2 - st*sqrtv1)); // 'rur' means 'row-upper-right'
+              const octave_idx_type cur = (octave_idx_type)std::fabs (k*(st*sqrtv2 + ct*sqrtv1));
+              const octave_idx_type rlr = (octave_idx_type)std::fabs (k*(ct*sqrtv2 + st*sqrtv1));
+              const octave_idx_type clr = (octave_idx_type)std::fabs (k*(st*sqrtv2 - ct*sqrtv1));
+              const octave_idx_type rul = (octave_idx_type)std::fabs (k*(-ct*sqrtv2 - st*sqrtv1));
+              const octave_idx_type cul = (octave_idx_type)std::fabs (k*(-st*sqrtv2 + ct*sqrtv1));
+              const octave_idx_type rll = (octave_idx_type)std::fabs (k*(-ct*sqrtv2 + st*sqrtv1));
+              const octave_idx_type cll = (octave_idx_type)std::fabs (k*(-st*sqrtv2 - ct*sqrtv1));
               const octave_idx_type r_delta = std::max (std::max (rur, rlr), std::max (rul, rll));
               const octave_idx_type c_delta = std::max (std::max (cur, clr), std::max (cul, cll));;
               // The bounding box is now (row-r_delta):(row+r_delta)x(col-c_delta):(col+c_delta).
