@@ -19,9 +19,7 @@
 //      -- Søren Hauberg, March 21st, 2008
 
 #include <octave/oct.h>
-
-#define WANTS_OCTAVE_IMAGE_VALUE 1
-#include "octave-wrappers.h"
+#include <octave/ov.h>
 
 /**
  * Filter functions for ordered filtering.
@@ -263,7 +261,7 @@ octave_value do_filtering (const MT &in,
   Array<octave_idx_type> se_sub   (dim_vector (ndims, 1), 0);
   Array<octave_idx_type> nnz_sub  (dim_vector (ndims, se_nnz));
   Array<Pin>             heights  (dim_vector (se_nnz, 1));
-  for (octave_idx_type i = 0, found = 0; found < se_nnz; i++)
+  for (octave_idx_type found = 0; found < se_nnz; )
     {
       if (se(se_sub))
         {
@@ -362,20 +360,12 @@ available in @code{rangefilt}.\n\
   octave_value_list retval;
   const octave_idx_type nargin = args.length ();
   if (nargin < 4)
-    {
-      print_usage ();
-      return retval;
-    }
+    print_usage ();
 
-  const octave_image::value A (args(0));
-  const octave_image::value S (args(3));
+  const octave_value A (args(0));
+  const octave_value S (args(3));
 
   const boolNDArray domain = args(1).bool_array_value ();
-  if (error_state)
-    {
-      error ("__spatial_filtering__: A must be a logical matrix");
-      return retval;
-    }
 
   octave_idx_type len = 0;
   for (octave_idx_type i = 0; i < domain.numel (); i++)
@@ -394,11 +384,6 @@ available in @code{rangefilt}.\n\
   int arg4 = (nargin == 4) ? 0 : args(4).int_value ();
 
   const std::string method = args(2).string_value ();
-  if (error_state)
-    {
-      error ("__spatial_filtering__: method must be a string");
-      return retval;
-    }
 
   #define GENERAL_ACTION(MT, FUN, ET, MT_OUT, ET_OUT, FILTER_FUN) \
     retval = do_filtering<MT, ET, MT_OUT, ET_OUT> (A.FUN (), domain, \
@@ -533,7 +518,7 @@ available in @code{rangefilt}.\n\
         ACTION (uint64NDArray, uint64_array_value, octave_uint64);
       else if (A.islogical ())
         ACTION (boolNDArray, bool_array_value, bool);
-      if (A.is_real_matrix ())
+      else if (A.is_real_matrix ())
         {
           if (A.is_single_type ())
             ACTION (FloatNDArray, float_array_value, float);
