@@ -40,6 +40,12 @@
 
  Edited in 2013 for C++, removed the #define stuff, and other
  fixes for matlab compatibility.
+ 
+ As discussed in 2022 in bug https://savannah.gnu.org/bugs/?62192
+ the results of the currently used algorithm can differ slightly
+ from the theoretically correct values. A more precise algorithm
+ can be found in the paper of Maurer, Rensheng Qi and V. Raghavan
+ https://doi.org/10.1109/TPAMI.2003.1177156 from 2003.
  */
 
 void edtfunc (float (*func)(short int, short int),
@@ -77,7 +83,7 @@ void edtfunc (float (*func)(short int, short int),
             {
               int tmp = distx[i+1] -1;
               // signed distance, to allow index calculation
-              if (abs (tmp) < distx[i])
+              if (std::abs (tmp) < distx[i])
                 distx[i] = tmp;
             }
         }
@@ -411,18 +417,18 @@ euclidean (short x, short y)
 
 static float
 chessboard (short x, short y)
-{ return std::max (abs (y), abs (x)); }
+{ return std::max (std::abs (y), std::abs (x)); }
 
 static float
 cityblock (short x, short y)
-{ return abs (x) + abs (y); }
+{ return std::abs (x) + std::abs (y); }
 
 static float
 quasi_euclidean (short x, short y)
 {
   static const float sqrt2_1 = sqrt (2) - 1;
-  return abs(x)>abs(y) ? (fabs(x) + sqrt2_1 * fabs(y)) :
-                         (sqrt2_1 * fabs(x) + fabs(y)) ;
+  return std::abs(x)>std::abs(y) ? (std::abs(x) + sqrt2_1 * std::abs(y)) :
+                                   (sqrt2_1 * std::abs(x) + std::abs(y)) ;
 }
 
 static FloatMatrix
@@ -487,6 +493,12 @@ The distance can be measured through different @var{method}s:\n\
 \n\
 Currently, only 2D images are supported.\n\
 \n\
+Note: This implementation of bwdist follows the algorithm of Per-Erik Danielsson\n\
+from 1980 (see source code for details). It gives fast and good results,\n\
+but they can slightly differ from the theoretically correct result and from\n\
+the Matlab result. Distance deviations are much smaller than a fraction\n\
+of a single pixel.\n\
+\n\
 @end deftypefn")
 {
   octave_value_list retval;
@@ -768,4 +780,14 @@ Currently, only 2D images are supported.\n\
 %! assert (dist, expected_dist)
 %! assert (idx, expected_idx)
 
+%!xtest
+%! # bug #62192
+%! a = zeros (200, 200);
+%! a (158, 100) = 1;
+%! a (141, 141) = 1;
+%! a (156, 115) = 1;
+%! d = bwdist (a);
+%! expected_result = single (57.9741);
+%! assert (d (100, 100), expected_result, 1e-4)
+
 */
