@@ -25,13 +25,11 @@
 #include <unordered_map>
 
 #include <octave/oct.h>
+#include <octave/ov.h>
 
 #include "union-find.h"
 #include "connectivity.h"
 
-#define WANTS_OCTAVE_IMAGE_VALUE 1
-#include "octave-wrappers.h"
-
 using namespace octave_image_pkg;
 
 static union_find
@@ -365,7 +363,7 @@ See, for example, http://en.wikipedia.org/wiki/Union-find\n\
   if (nargin < 1 || nargin > 2)
     print_usage ();
 
-  octave_image::value bw_value (args(0));
+  octave_value bw_value (args(0));
   if (! bw_value.isnumeric () && ! bw_value.islogical ())
     error ("bwlabeln: BW must be a numeric or logical matrix");
 
@@ -665,7 +663,7 @@ can be changed through the argument @var{n}, which can be either 4, 6, or 8.\n\
   // We do not check error state after conversion to boolMatrix
   // because what we want is to actually get a boolean matrix
   // with all non-zero elements as true (Matlab compatibility).
-  octave_image::value bw_value (args(0));
+  octave_value bw_value (args(0));
   if ((! bw_value.isnumeric () && ! bw_value.islogical ()) ||
       bw_value.ndims () != 2)
     error ("bwlabel: BW must be a 2D matrix");
