@@ -21,9 +21,7 @@
 #include <typeinfo>
 
 #include <octave/oct.h>
-
-#define WANTS_OCTAVE_IMAGE_VALUE 1
-#include "octave-wrappers.h"
+#include <octave/ov.h>
 
 using namespace octave_image_pkg;
 
@@ -296,10 +294,8 @@ connectivity::padding_mask (const dim_vector& size,
 
 
 connectivity
-octave_image_pkg::conndef (const octave_value& _val)
+octave_image_pkg::conndef (const octave_value& val)
 {
-  octave_image::value val (_val);
-
   // A mask may not not be of type logical/bool, it can be of any
   // numeric type as long all values are zeros and ones (usually
   // manually typed masks which by default are of type double.
