@@ -29,12 +29,6 @@
 
 #include <octave/ov.h>
 
-#if defined (HAVE_OCTAVE_DIM_VECTOR_XELEM)
-#  define OCT_DIM_VECTOR_XELEM xelem
-#else
-#  define OCT_DIM_VECTOR_XELEM elem
-#endif
-
 namespace octave_image_pkg
 {
     class connectivity
@@ -156,7 +150,7 @@ octave_image_pkg::connectivity::set_padding (const dim_vector& size,
   const Array<octave_idx_type> lengths = padding_lengths (size, padded_size);
   const octave_idx_type* lengths_v = lengths.data ();
 
-  const octave_idx_type row_stride = size.OCT_DIM_VECTOR_XELEM (0);
+  const octave_idx_type row_stride = size.xelem (0);
 
   std::function<void(const octave_idx_type)> fill;
   fill = [&] (const octave_idx_type dim) -> void
@@ -167,7 +161,7 @@ octave_image_pkg::connectivity::set_padding (const dim_vector& size,
     if (dim == 0)
       im_v += row_stride;
     else
-      for (octave_idx_type i = 0; i < size.OCT_DIM_VECTOR_XELEM (dim); i++)
+      for (octave_idx_type i = 0; i < size.xelem (dim); i++)
         fill (dim -1);
 
     for (octave_idx_type i = 0; i < lengths_v[dim]; i++, im_v++)
